@@ -1,3 +1,6 @@
+#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  SPDX-License-Identifier: Apache-2.0
+
 import luigi
 
 from servicecatalog_puppet import constants
@@ -14,3 +17,7 @@ class LambdaInvocationBaseTask(tasks.PuppetTask):
     @property
     def item_name(self):
         return self.lambda_invocation_name
+
+    @property
+    def item_identifier(self):
+        return "lambda_invocation_name"
